# eric7.Debugger.DebuggerInterfaceNone

Module implementing a dummy debugger interface for the debug server.

### Global Attributes

ClientDefaultCapabilities
ClientTypeAssociations

### Classes

DebuggerInterfaceNone | Class implementing a dummy debugger interface for the debug server.

### Functions

createDebuggerInterfaceNone | Module function to create a debugger interface instance.
getRegistryData | Module function to get characterizing data for the debugger interface.

## DebuggerInterfaceNone

Class implementing a dummy debugger interface for the debug server.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

DebuggerInterfaceNone | Constructor
getClientCapabilities | Public method to retrieve the debug clients capabilities.
getDebuggerIds | Public method to return the IDs of the connected debugger backends.
isConnected | Public method to test, if a debug client has connected.
newConnection | Public slot to handle a new connection.
remoteBanner | Public slot to get the banner info of the remote client.
remoteBreakpoint | Public method to set or clear a breakpoint.
remoteBreakpointEnable | Public method to enable or disable a breakpoint.
remoteBreakpointIgnore | Public method to ignore a breakpoint the next couple of occurrences.
remoteCapabilities | Public slot to get the debug clients capabilities.
remoteClientDisassembly | Public method to ask the client for the latest traceback disassembly.
remoteClientSetFilter | Public method to set a variables filter list.
remoteClientStack | Public method to request the stack of the main thread.
remoteClientVariable | Public method to request the variables of the debugged program.
remoteClientVariables | Public method to request the variables of the debugged program.
remoteCompletion | Public slot to get the a list of possible commandline completions from the remote client.
remoteContinue | Public method to continue the debugged program.
remoteContinueUntil | Public method to continue the debugged program to the given line or until returning from the current frame.
remoteCoverage | Public method to load a new program to collect coverage data.
remoteEnvironment | Public method to set the environment for a program to debug, run, ...
remoteLoad | Public method to load a new program to debug.
remoteMoveIP | Public method to move the instruction pointer to a different line.
remoteNoDebugList | Public method to set a list of programs not to be debugged.
remoteProfile | Public method to load a new program to collect profiling data.
remoteRawInput | Public method to send the raw input to the debugged program.
remoteRun | Public method to load a new program to run.
remoteSetThread | Public method to request to set the given thread as current thread.
remoteStatement | Public method to execute a Python statement.
remoteStep | Public method to single step the debugged program.
remoteStepOut | Public method to step out the debugged program.
remoteStepOver | Public method to step over the debugged program.
remoteStepQuit | Public method to stop the debugged program.
remoteThreadList | Public method to request the list of threads from the client.
remoteWatchpoint | Public method to set or clear a watch expression.
remoteWatchpointEnable | Public method to enable or disable a watch expression.
remoteWatchpointIgnore | Public method to ignore a watch expression the next couple of occurrences.
setCallTraceEnabled | Public method to set the call trace state.
shutdown | Public method to cleanly shut down.
startRemote | Public method to start a remote Python interpreter.
startRemoteForProject | Public method to start a remote Python interpreter for a project.

### Static Methods

None

#### DebuggerInterfaceNone (Constructor)

DebuggerInterfaceNone(debugServer, passive)

Constructor

debugServer (DebugServer)
  reference to the debug server
passive (bool)
  flag indicating passive connection mode

#### DebuggerInterfaceNone.getClientCapabilities

getClientCapabilities()

Public method to retrieve the debug clients capabilities.

Return:
  debug client capabilities

Return Type:
  int

#### DebuggerInterfaceNone.getDebuggerIds

getDebuggerIds()

Public method to return the IDs of the connected debugger backends.

Return:
  list of connected debugger backend IDs

Return Type:
  list of str

#### DebuggerInterfaceNone.isConnected

isConnected()

Public method to test, if a debug client has connected.

Return:
  flag indicating the connection status

Return Type:
  bool

#### DebuggerInterfaceNone.newConnection

newConnection(sock)

Public slot to handle a new connection.

sock (QTcpSocket)
  reference to the socket object

Return:
  flag indicating success

Return Type:
  bool

#### DebuggerInterfaceNone.remoteBanner

remoteBanner()

Public slot to get the banner info of the remote client.

#### DebuggerInterfaceNone.remoteBreakpoint

remoteBreakpoint(debuggerId, fn, line, setBreakpoint, cond=None, temp=False)

Public method to set or clear a breakpoint.

debuggerId (str)
  ID of the debugger backend
fn (str)
  filename the breakpoint belongs to
line (int)
  linenumber of the breakpoint
setBreakpoint (bool)
  flag indicating setting or resetting a breakpoint
cond (str)
  condition of the breakpoint
temp (bool)
  flag indicating a temporary breakpoint

#### DebuggerInterfaceNone.remoteBreakpointEnable

remoteBreakpointEnable(debuggerId, fn, line, enable)

Public method to enable or disable a breakpoint.

debuggerId (str)
  ID of the debugger backend
fn (str)
  filename the breakpoint belongs to
line (int)
  linenumber of the breakpoint
enable (bool)
  flag indicating enabling or disabling a breakpoint

#### DebuggerInterfaceNone.remoteBreakpointIgnore

remoteBreakpointIgnore(debuggerId, fn, line, count)

Public method to ignore a breakpoint the next couple of occurrences.

debuggerId (str)
  ID of the debugger backend
fn (str)
  filename the breakpoint belongs to
line (int)
  linenumber of the breakpoint
count (int)
  number of occurrences to ignore

#### DebuggerInterfaceNone.remoteCapabilities

remoteCapabilities(debuggerId)

Public slot to get the debug clients capabilities.

debuggerId (str)
  ID of the debugger backend

#### DebuggerInterfaceNone.remoteClientDisassembly

remoteClientDisassembly(debuggerId)

Public method to ask the client for the latest traceback disassembly.

debuggerId (str)
  ID of the debugger backend

#### DebuggerInterfaceNone.remoteClientSetFilter

remoteClientSetFilter(debuggerId, scope, filterStr)

Public method to set a variables filter list.

debuggerId (str)
  ID of the debugger backend
scope (int)
  the scope of the variables (0 = local, 1 = global)
filterStr (str)
  regexp string for variable names to filter out

#### DebuggerInterfaceNone.remoteClientStack

remoteClientStack(debuggerId)

Public method to request the stack of the main thread.

debuggerId (str)
  ID of the debugger backend

#### DebuggerInterfaceNone.remoteClientVariable

remoteClientVariable(debuggerId, scope, filterList, var, framenr=0, maxSize=0)

Public method to request the variables of the debugged program.

debuggerId (str)
  ID of the debugger backend
scope (int)
  the scope of the variables (0 = local, 1 = global)
filterList (list of str)
  list of variable types to filter out
var (list of str)
  list encoded name of variable to retrieve
framenr (int)
  framenumber of the variables to retrieve
maxSize (int)
  maximum size the formatted value of a variable will be shown. If it is bigger than that, a 'too big' indication will be given (@@TOO_BIG_TO_SHOW@@).

#### DebuggerInterfaceNone.remoteClientVariables

remoteClientVariables(debuggerId, scope, filterList, framenr=0, maxSize=0)

Public method to request the variables of the debugged program.

debuggerId (str)
  ID of the debugger backend
scope (int)
  the scope of the variables (0 = local, 1 = global)
filterList (list of str)
  list of variable types to filter out
framenr (int)
  framenumber of the variables to retrieve
maxSize (int)
  maximum size the formatted value of a variable will be shown. If it is bigger than that, a 'too big' indication will be given (@@TOO_BIG_TO_SHOW@@).

#### DebuggerInterfaceNone.remoteCompletion

remoteCompletion(debuggerId, text)

Public slot to get the a list of possible commandline completions from the remote client.

debuggerId (str)
  ID of the debugger backend
text (str)
  the text to be completed

#### DebuggerInterfaceNone.remoteContinue

remoteContinue(debuggerId, special=False)

Public method to continue the debugged program.

debuggerId (str)
  ID of the debugger backend
special (bool)
  flag indicating a special continue operation

#### DebuggerInterfaceNone.remoteContinueUntil

remoteContinueUntil(debuggerId, line)

Public method to continue the debugged program to the given line or until returning from the current frame.

debuggerId (str)
  ID of the debugger backend
line (int)
  the new line, where execution should be continued to

#### DebuggerInterfaceNone.remoteCoverage

remoteCoverage(fn, argv, wd, erase=False)

Public method to load a new program to collect coverage data.

fn (str)
  the filename to run
argv (str)
  the commandline arguments to pass to the program
wd (str)
  the working directory for the program
erase (bool)
  flag indicating that coverage info should be cleared first

#### DebuggerInterfaceNone.remoteEnvironment

remoteEnvironment(env)

Public method to set the environment for a program to debug, run, ...

env (dict)
  environment settings

#### DebuggerInterfaceNone.remoteLoad

remoteLoad(fn, argv, wd, traceInterpreter=False, autoContinue=True, enableMultiprocess=False, )

Public method to load a new program to debug.

fn (str)
  the filename to debug
argv (str)
  the commandline arguments to pass to the program
wd (str)
  the working directory for the program
traceInterpreter (bool)
  flag indicating if the interpreter library should be traced as well
autoContinue (bool)
  flag indicating, that the debugger should not stop at the first executable line
enableMultiprocess (bool)
  flag indicating to perform multiprocess debugging

#### DebuggerInterfaceNone.remoteMoveIP

remoteMoveIP(debuggerId, line)

Public method to move the instruction pointer to a different line.

debuggerId (str)
  ID of the debugger backend
line (int)
  the new line, where execution should be continued

#### DebuggerInterfaceNone.remoteNoDebugList

remoteNoDebugList(debuggerId, noDebugList)

Public method to set a list of programs not to be debugged.

The programs given in the list will not be run under the control of the multi process debugger.

debuggerId (str)
  ID of the debugger backend
noDebugList (list of str)
  list of Python programs not to be debugged

#### DebuggerInterfaceNone.remoteProfile

remoteProfile(fn, argv, wd, erase=False)

Public method to load a new program to collect profiling data.

fn (str)
  the filename to run
argv (str)
  the commandline arguments to pass to the program
wd (str)
  the working directory for the program
erase (bool)
  flag indicating that timing info should be cleared first

#### DebuggerInterfaceNone.remoteRawInput

remoteRawInput(debuggerId, inputString)

Public method to send the raw input to the debugged program.

debuggerId (str)
  ID of the debugger backend
inputString (str)
  the raw input

#### DebuggerInterfaceNone.remoteRun

remoteRun(fn, argv, wd)

Public method to load a new program to run.

fn (str)
  the filename to run
argv (str)
  the commandline arguments to pass to the program
wd (str)
  the working directory for the program

#### DebuggerInterfaceNone.remoteSetThread

remoteSetThread(debuggerId, tid)

Public method to request to set the given thread as current thread.

debuggerId (str)
  ID of the debugger backend
tid (int)
  id of the thread

#### DebuggerInterfaceNone.remoteStatement

remoteStatement(debuggerId, stmt)

Public method to execute a Python statement.

debuggerId (str)
  ID of the debugger backend
stmt (str)
  the Python statement to execute.

#### DebuggerInterfaceNone.remoteStep

remoteStep(debuggerId)

Public method to single step the debugged program.

debuggerId (str)
  ID of the debugger backend

#### DebuggerInterfaceNone.remoteStepOut

remoteStepOut(debuggerId)

Public method to step out the debugged program.

debuggerId (str)
  ID of the debugger backend

#### DebuggerInterfaceNone.remoteStepOver

remoteStepOver(debuggerId)

Public method to step over the debugged program.

debuggerId (str)
  ID of the debugger backend

#### DebuggerInterfaceNone.remoteStepQuit

remoteStepQuit(debuggerId)

Public method to stop the debugged program.

debuggerId (str)
  ID of the debugger backend

#### DebuggerInterfaceNone.remoteThreadList

remoteThreadList(debuggerId)

Public method to request the list of threads from the client.

debuggerId (str)
  ID of the debugger backend

#### DebuggerInterfaceNone.remoteWatchpoint

remoteWatchpoint(debuggerId, cond, setWatch, temp=False)

Public method to set or clear a watch expression.

debuggerId (str)
  ID of the debugger backend
cond (str)
  expression of the watch expression
setWatch (bool)
  flag indicating setting or resetting a watch expression
temp (bool)
  flag indicating a temporary watch expression

#### DebuggerInterfaceNone.remoteWatchpointEnable

remoteWatchpointEnable(debuggerId, cond, enable)

Public method to enable or disable a watch expression.

debuggerId (str)
  ID of the debugger backend
cond (str)
  expression of the watch expression
enable (bool)
  flag indicating enabling or disabling a watch expression

#### DebuggerInterfaceNone.remoteWatchpointIgnore

remoteWatchpointIgnore(debuggerId, cond, count)

Public method to ignore a watch expression the next couple of occurrences.

debuggerId (str)
  ID of the debugger backend
cond (str)
  expression of the watch expression
count (int)
  number of occurrences to ignore

#### DebuggerInterfaceNone.setCallTraceEnabled

setCallTraceEnabled(debuggerId, on)

Public method to set the call trace state.

debuggerId (str)
  ID of the debugger backend
on (bool)
  flag indicating to enable the call trace function

#### DebuggerInterfaceNone.shutdown

shutdown()

Public method to cleanly shut down.

It closes our socket and shuts down the debug client. (Needed on Win OS)

#### DebuggerInterfaceNone.startRemote

startRemote(port, runInConsole, venvName, originalPathString, workingDir=None, configOverride=None, )

Public method to start a remote Python interpreter.

port (int)
  port number the debug server is listening on
runInConsole (bool)
  flag indicating to start the debugger in a console window
venvName (str)
  name of the virtual environment to be used
originalPathString (str)
  original PATH environment variable
workingDir (str)
  directory to start the debugger client in
configOverride (dict)
  dictionary containing the global config override data

Return:
  client process object, a flag to indicate a network connection and the name of the interpreter in case of a local execution

Return Type:
  tuple of (QProcess, bool, str)

#### DebuggerInterfaceNone.startRemoteForProject

startRemoteForProject(port, runInConsole, venvName, originalPathString, workingDir=None, configOverride=None, )

Public method to start a remote Python interpreter for a project.

port (int)
  port number the debug server is listening on
runInConsole (bool)
  flag indicating to start the debugger in a console window
venvName (str)
  name of the virtual environment to be used
originalPathString (str)
  original PATH environment variable
workingDir (str)
  directory to start the debugger client in
configOverride (dict)
  dictionary containing the global config override data

Return:
  client process object, a flag to indicate a network connection and the name of the interpreter in case of a local execution

Return Type:
  tuple of (QProcess, bool, str)

Up

## createDebuggerInterfaceNone

createDebuggerInterfaceNone(debugServer, passive)

Module function to create a debugger interface instance.

debugServer (DebugServer)
  reference to the debug server
passive (bool)
  flag indicating passive connection mode

Return:
  instantiated debugger interface

Return Type:
  DebuggerInterfaceNone

Up

## getRegistryData

getRegistryData()

Module function to get characterizing data for the debugger interface.

Return:
  list of tuples containing the client type, the client capabilities, the client file type associations and a reference to the creation function

Return Type:
  list of tuple of (str, int, list of str, function)

Up